@@ -11,11 +11,13 @@ from hubitat_maker_api_client.event_socket import HubitatEvent
 ATTR_KEY_TO_CAPABILITY = {
     'battery': 'MotionSensor',
     'contact': 'ContactSensor',
+    'energy': 'EnergyMeter',
+    'illuminance': 'IlluminanceMeasurement',
     'lock': 'Lock',
     'motion': 'MotionSensor',
-    'switch': 'Switch',
+    'power': 'PowerMeter',
     'presence': 'PresenceSensor',
-    'illuminance': 'IlluminanceMeasurement',
+    'switch': 'Switch',
 }
 
 
@@ -119,7 +121,7 @@ class HubitatCachingClient(HubitatClient):
 
         alias = getattr(event, self.event_key)
 
-        capabilities = self.get_capabilities_for_device_id(event.device_id) or {None}
+        capabilities = self.get_capabilities_for_device_id(event.device_id) or {None}  # type: ignore
 
         for capability in capabilities:
             for cap, k, v in SUPPORTED_ACCESSOR_ATTRS:
